==> pytest-logfest-0.1.0.tar.gz: pytest-logfest-0.1.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import codecs
from setuptools import setup


def read(fname):
    file_path = os.path.join(os.path.dirname(__file__), fname)
    return codecs.open(file_path, encoding='utf-8').read()


setup(
    name='pytest-logfest',
    version='0.1.0',
    author='Joep Schuurkes',
    author_email='j19sch@gmail.com',
    maintainer='Joep Schuurkes',
    maintainer_email='j19sch@gmail.com',
    license='MIT',
    url='https://github.com/j19sch/pytest-logfest',
    description='Pytest plugin to write test logs to file(s)',
    long_description=read('README.rst'),
    packages=['pytest_logfest'],
    python_requires='>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*',
    install_requires=['pytest>=3.5.0', 'pathlib2'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Pytest',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Testing',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: MIT License',
    ],
    entry_points={
        'pytest11': [
            'logfest = pytest_logfest.plugin',
        ],
    },
)

==> pytest-logfest-0.2.0.tar.gz: pytest-logfest-0.2.0/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import os
import codecs
from setuptools import setup


def read(fname):
    file_path = os.path.join(os.path.dirname(__file__), fname)
    return codecs.open(file_path, encoding='utf-8').read()


setup(
    name='pytest-logfest',
    version='0.2.0',
    author='Joep Schuurkes',
    author_email='j19sch@gmail.com',
    maintainer='Joep Schuurkes',
    maintainer_email='j19sch@gmail.com',
    license='MIT',
    url='https://github.com/j19sch/pytest-logfest',
    description='Pytest plugin providing three logger fixtures with basic or full writing to log files',
    long_description=read('README.rst'),
    packages=['pytest_logfest'],
    python_requires='>=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*',
    install_requires=['pytest>=3.5.0', 'pathlib2'],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Framework :: Pytest',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Testing',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
        'Operating System :: OS Independent',
        'License :: OSI Approved :: MIT License',
    ],
    entry_points={
        'pytest11': [
            'logfest = pytest_logfest.plugin',
        ],
    },
)
